@@ -26,10 +26,12 @@ class Aggregate(Enum):
     DOMINANT = "dominant"
     FIRST_BY_INDEX = "first by index"
     LAST_BY_INDEX = "last by index"
+    LAST_MINUS_FIRST = "last minus first"
     LAST = "last"
     HIGH = "high"
     JOIN = "join"
     LOW = "low"
+    HIGH_MINUS_LOW = "high minus low"
     MEAN = "mean"
     MEDIAN = "median"
     OR = "or"
