@@ -11,18 +11,21 @@
 
 #include <perspective/base.h>
 #include <perspective/binding.h>
+#include <perspective/pyutils.h>
 #include <perspective/python/base.h>
 
 namespace perspective {
 namespace binding {
 
-/******************************************************************************
- *
- * Table API
- */
-std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor, std::uint32_t limit, py::str index, t_op op, bool is_update, bool is_arrow, t_uindex port_id);
+    /******************************************************************************
+     *
+     * Table API
+     */
+    std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
+        std::uint32_t limit, std::string index, t_op op, bool is_update,
+        bool is_arrow, bool is_csv, t_uindex port_id);
 
-} //namespace binding
-} //namespace perspective
+} // namespace binding
+} // namespace perspective
 
 #endif
\ No newline at end of file
